@@ -1,4 +1,4 @@
-.onAttach <- function (libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   msg <- paste("Loading 'meta' package (version ",
                utils::packageDescription("meta")$Version,
                ").",
@@ -213,3 +213,28 @@ setOption("test.overall", FALSE)
 setOption("test.subgroup", FALSE)
 setOption("test.effect.subgroup", FALSE)
 setOption("digits.forest", 2)
+
+
+setOption("Wan2014.Table1",
+          c(0.000, 1.128, 1.693, 2.059, 2.326,
+            2.534, 2.704, 2.847, 2.970, 3.078,
+            3.173, 3.259, 3.336, 3.407, 3.472,
+            3.532, 3.588, 3.640, 3.689, 3.735,
+            3.778, 3.819, 3.858, 3.895, 3.931,
+            3.964, 3.997, 4.027, 4.057, 4.086,
+            4.113, 4.139, 4.165, 4.189, 4.213,
+            4.236, 4.259, 4.280, 4.301, 4.322,
+            4.341, 4.361, 4.379, 4.398, 4.415,
+            4.433, 4.450, 4.466, 4.482, 4.498))
+##
+setOption("Wan2014.Table2",
+          c(0.990, 1.144, 1.206, 1.239, 1.260,
+            1.274, 1.284, 1.292, 1.298, 1.303,
+            1.307, 1.311, 1.313, 1.316, 1.318,
+            1.320, 1.322, 1.323, 1.324, 1.326,
+            1.327, 1.328, 1.329, 1.330, 1.330,
+            1.331, 1.332, 1.332, 1.333, 1.333,
+            1.334, 1.334, 1.335, 1.335, 1.336,
+            1.336, 1.336, 1.337, 1.337, 1.337,
+            1.338, 1.338, 1.338, 1.338, 1.339,
+            1.339, 1.339, 1.339, 1.339, 1.340))
